# Installation

## Requires
```
tensorflow, tensorflow-gpu, numpy, scipy
```
and additional package for fast signal propagation calculation
```
pip install hpcom
```

## Local installation

If for some reason you need to install package locally, you can use wheel file for package
```
pip install wheel
pip install wheel_file.whl  # directly install the wheel
```
or use alternative command
```
python -m wheel install wheel_file.whl
```